@@ -11,7 +11,7 @@ refresh <- function(input, output){
   
   # This reactive takes the input data and sends it over to the simulator
   # Then it will get the results back and return it as the "res" variable
-  res <- reactive({
+  result <- reactive({
     input$submitBtn
     
     # Read all the input values from the UI
@@ -27,58 +27,113 @@ refresh <- function(input, output){
     A = isolate(input$A);
     scenario = as.numeric(isolate(input$scenario));
     
+    plotscale = isolate(input$plotscale) #---
     
-    # Call the ODE solver with the given parameters
+    #save all results to a list for processing plots and text
+    listlength = 1; #here we do all simulations in the same figure
+    result = vector("list", listlength) #create empty list of right size for results
     
-    result <- simulate_directtransmission(S0 = S0, I0 = I0, tmax = tmax, scenario = scenario, bd = bd, bf = bf, A = A, m = m, n = n, g = g, w = w)
+    #shows a 'running simulation' message
+    withProgress(message = 'Running Simulation', value = 0,
+                 {
+      simresult <- simulate_directtransmission(S0 = S0, I0 = I0, tmax = tmax, scenario = scenario, bd = bd, bf = bf, A = A, m = m, n = n, g = g, w = w)
 
-    return(list(result)) #this is returned as the res variable
-  })
+                 }) 
+    
+    
+    dat <- simresult$ts
+    
+    #data for plots and text
+    #each variable listed in the varnames column will be plotted on the y-axis, with its values in yvals
+    #each variable listed in varnames will also be processed to produce text
+    result[[1]]$dat = dat
+    
+    # Meta-information for each plot
+    result[[1]]$plottype = "Lineplot"
+    result[[1]]$xlab = "Time"
+    result[[1]]$ylab = "Numbers"
+    result[[1]]$legend = "Compartments"
+
+    result[[1]]$xscale = 'identity'
+    result[[1]]$yscale = 'identity'
+    if (plotscale == 'x' | plotscale == 'both') { result[[1]]$xscale = 'log10'}
+    if (plotscale == 'y' | plotscale == 'both') { result[[1]]$yscale = 'log10'}
+    
+    #the following are for text display for each plot
+    
+    result[[1]]$maketext = TRUE #if true we want the generate_text function to process data and generate text, if 0 no result processing will occur insinde generate_text
+    result[[1]]$showtext = '' #text can be added here which will be passed through to generate_text and displayed for each plot
+    result[[1]]$finaltext = 'Numbers are rounded to 2 significant digits.' #text can be added here which will be passed through to generate_text and displayed for each plot
+    
+    return(result)
+    
+  })          #ends inner shiny server function that runs the simulation and returns output
   
-  #function that takes result saved in res and produces output
-  #output (plots, text, warnings) is stored in and modifies the global variable 'output'
-  generate_simoutput(input,output,res)
-} #ends the 'refresh' shiny server function that runs the simulation and returns output
+  
+  #functions below take result saved in reactive expression result and produce output
+  #to produce figures, the function generate_plot is used
+  #function generate_text produces text
+  #data needs to be in a specific structure for processing
+  #see information for those functions to learn how data needs to look like
+  #output (plots, text) is stored in reactive variable 'output'
+  
+  output$plot  <- renderPlot({
+          input$submitBtn
+          res=isolate(result())             #list of all results that are to be turned into plots
+          generate_plots(res)              #create plots with a non-reactive function
+      }, width = 'auto', height = 'auto'
+  )                                       #finish render-plot statement
+  
+  output$text <- renderText({
+         input$submitBtn
+         res=isolate(result())     #list of all results that are to be turned into plots
+         generate_text(res)         #create text for display with a non-reactive function
+    })
+  
+  }             #ends the 'refresh' shiny server function that runs the simulation and returns output   
+
 
 #main shiny server function
+
 server <- function(input, output, session) {
   
-  # Waits for the Exit Button to be pressed to stop the app and return to main menu
-  observeEvent(input$exitBtn, {
-    input$exitBtn
-    stopApp(returnValue = 0)
+          # Waits for the Exit Button to be pressed to stop the app and return to main menu
+      observeEvent(input$exitBtn, {
+      input$exitBtn
+      stopApp(returnValue = NULL)
   })
   
   # This function is called to refresh the content of the Shiny App
-  refresh(input, output)
   
-  # Event handler to listen for the webpage and see when it closes.
-  # Right after the window is closed, it will stop the app server and the main menu will
-  # continue asking for inputs.
-  session$onSessionEnded(function(){
-    stopApp(returnValue = 0)
-  })
-} #ends the main shiny server function
+  refresh(input, output)
+ 
+ }                        #ends the main shiny server function
 
 
 #This is the UI part of the shiny App
+
 ui <- fluidPage(
-  includeCSS("../styles/dsaide.css"),
-  #add header and title
-   
-  div( includeHTML("www/header.html"), align = "center"),
-  #specify name of App below, will show up in title
-  h1('Modes of Direct Transmission App', align = "center", style = "background-color:#123c66; color:#fff"),
   
-  #section to add buttons
-  fluidRow(
-    column(6,
-           actionButton("submitBtn", "Run Simulation", class="submitbutton")  
-    ),
-    column(6,
-           actionButton("exitBtn", "Exit App", class="exitbutton")
-    ),
-    align = "center"
+     includeCSS("../../media/dsaide.css"), 
+     
+   #add header and title
+   
+     div( includeHTML("../../media/header.html"), align = "center"),
+  
+   #specify name of App below, will show up in title
+  
+    h1('Modes of Direct Transmission App', align = "center", style = "background-color:#123c66; color:#fff"),
+  
+  #section to add the submit and exit buttons
+  
+   fluidRow(
+         column(6,align = "center",
+                 actionButton("submitBtn", "Run Simulation", class="submitbutton")  
+      ),
+        column(6,
+                actionButton("exitBtn", "Exit App", class="exitbutton")
+     )
+        
   ), #end section to add buttons
   
   tags$hr(),
@@ -90,15 +145,16 @@ ui <- fluidPage(
     column(6,
            #################################
            # Inputs section
-           h2('Simulation Settings'),
-           fluidRow(
+           h2('Simulation Settings'), # header for the Input section 
+           
+           fluidRow(  # first row of the input section 
              column(6,
                     numericInput("S0", "initial number of susceptible hosts (S0)", min = 1000, max = 5000, value = 1000, step = 500)
              ),
              column(6,
                     numericInput("I0", "initial number of infected hosts (I0)", min = 0, max = 100, value = 0, step = 1)
              )
-           ), #close fluidRow structure for input
+           ), #close row of the input section
            fluidRow(
              column(6,
                     numericInput("tmax", "Maximum simulation time (tmax)", min = 1, max = 500, value = 100, step = 1)
@@ -132,11 +188,17 @@ ui <- fluidPage(
              ),
              column(4,
                     numericInput("n", "Natural death rate (n)", min = 0, max = 0.02, value = 0, step = 0.0005 )
+             )
+             
+           ),
+           fluidRow(
+             column(6,
+                    selectInput("plotscale", "Log-scale for plot:",c("none" = "none", 'x-axis' = "x", 'y-axis' = "y", 'both axes' = "both"))
              ),
+             
              align = "center"
-           ) #close fluidRow structure for input
-           
-    ), #end sidebar column for inputs
+              ) 
+           ), #close fluidRow structure for inpu
 
     #all the outcomes here
     column(6,
@@ -162,9 +224,10 @@ ui <- fluidPage(
   #Instructions section at bottom as tabs
   h2('Instructions'),
   #use external function to generate all tabs with instruction content
-  do.call(tabsetPanel,generate_instruction_tabs()),
-  div(includeHTML("www/footer.html"), align="center", style="font-size:small") #footer
+  # do.call(tabsetPanel,generate_instruction_tabs()),
+  do.call(tabsetPanel, generate_documentation()),
+  div(includeHTML("../../media/footer.html"), align="center", style="font-size:small") #footer
   
 ) #end fluidpage function, i.e. the UI part of the app
 
-shinyApp(ui = ui, server = server)
\ No newline at end of file
+shinyApp(ui = ui, server = server)
